#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "animationbar.h"

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
    , ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    connect(ui->BUTTON_createExternalWebView,SIGNAL(clicked(bool)),this,SLOT(createExternalWebView(bool)));
    connect(ui->BUTTON_createInternalWebView,SIGNAL(clicked(bool)),this,SLOT(createInternalWebView(bool)));
    connect(ui->BUTTON_killWebView,SIGNAL(clicked(bool)),this,SLOT(killWebView(bool)));
    connect(ui->BUTTON_runAnims,SIGNAL(clicked(bool)),this,SLOT(runAnims(bool)));
}

void MainWindow::runAnims(bool is){
    QList<AnimationBar *> allBars = ui->ZONE_anims->findChildren<AnimationBar *>();
    for (int k=0;k<allBars.length();k++){
        AnimationBar* thisBar=allBars.at(k);
        thisBar->setPourcent((double)(50.0)+(double)(QRandomGenerator::global()->generate()%50),false);
    }
}
void MainWindow::killWebView(bool is){
    if (mWebEngineView!=nullptr) mWebEngineView->stop();
    mPopup->deleteLater();
    mWebEngineView->deleteLater();
    mLayoutForBrowse->deleteLater();
    mWebEnginePage->deleteLater();
    mPopup=nullptr;
    mWebEngineView=nullptr;
    mLayoutForBrowse=nullptr;
    mWebEnginePage=nullptr;
}
void MainWindow::createExternalWebView(bool is){
    createWebView(is);

    mPopup = new SimpleWindow(this);
    mPopup->show();
    if (mLayoutForBrowse==nullptr) mLayoutForBrowse=new QVBoxLayout(mPopup->centralWidget());
    qDeleteAll(mLayoutForBrowse->children());
    mLayoutForBrowse->addWidget(mWebEngineView);

    mPopup->resize(ui->ZONE_webview->width(),ui->ZONE_webview->height());
    fitExternalWebView();
}
void MainWindow::fitExternalWebView(){
    if (mPopup!=nullptr){
        QPoint pt=ui->ZONE_webview->mapToGlobal(QPoint(0,0));
        mPopup->move(pt.x(),pt.y());
    }
}
void MainWindow::createInternalWebView(bool is){
    createWebView(is);

    if (mLayoutForBrowse==nullptr) mLayoutForBrowse=new QVBoxLayout(ui->ZONE_webview);
    qDeleteAll(mLayoutForBrowse->children());
    mLayoutForBrowse->addWidget(mWebEngineView);
}
void MainWindow::createWebView(bool is){
    killWebView(is);
    mWebEngineView = new QWebEngineView();//can't link to this, for compatibility with my project
    mWebEnginePage = new QWebEnginePage(mWebEngineView);
    mWebEnginePage->setView(mWebEngineView);
    connect(mWebEnginePage,SIGNAL(loadFinished(bool)),this,SLOT(webPageReady(bool)));

    mWebEngineView->setUrl(QUrl("http://www.google.com"));
}
void MainWindow::webPageReady(bool ok){
    mWebEngineView->show();
    disconnect(mWebEnginePage,SIGNAL(loadFinished(bool)),this,SLOT(webPageReady(bool)));
}
void MainWindow::moveEvent(QMoveEvent *e){
    fitExternalWebView();
}
MainWindow::~MainWindow(){
    killWebView(true);
    delete ui;
}
/*
void MainWindow::runTimers(bool is){
    QList<AnimationBar *> allBars = ui->ZONE_anims->findChildren<AnimationBar *>();
    for (int k=0;k<allBars.length();k++){
        AnimationBar* thisBar=allBars.at(k);
        thisBar->setPourcent((double)(50.0)+(double)(QRandomGenerator::global()->generate()%50),true);
    }
}
void MainWindow::saveImage(){
    QRect size(mWebEngineView->contentsRect());
    QPixmap img(size.width(), size.height());
    mWebEngineView->render(&img);
    img.save("tmp.jpg");
    mWebEngineView->close();
}
void MainWindow::pdfPrintingFinished(const QString &filePath, bool success){
    qDebug() << "MainWindow::pdfPrintingFinished";
    disconnect(mWebEnginePage, &QWebEnginePage::pdfPrintingFinished,this, &MainWindow::pdfPrintingFinished);
}
*/
